Module error

Module error 

Error types returned by every fallible operation in this crate. Error types for Java environment detection and execution.

Enums

JavaError
Errors that can occur when working with Java installations.