Module local

Module local 

Local Java installation management

Functions

find_all_java_installations
Discovers all Java installations on the system.
get_java_by_version
Gets information about a specific Java installation by version.
get_java_document
Gets the Java documentation directory.
get_java_dyn_lib
Gets the directory containing the JVM dynamic library.
get_java_home
Gets detailed information about the current Java installation.
get_latest_java
Gets the latest Java installation available on the system.