pub struct JavaRedirect { /* private fields */ }Expand description
I/O redirection options for a Java process.
Use the builder methods to specify files for stdout, stderr, and stdin. If a stream is not redirected, it will inherit the parent’s corresponding stream (i.e., print to console or read from keyboard).
Implementations
Sourceimpl JavaRedirect
impl JavaRedirect
Sourcepub fn output(self, path: impl AsRef<Path>) -> Self
pub fn output(self, path: impl AsRef<Path>) -> Self
Redirects the Java process’s standard output to the given file. The file will be created (or truncated) before execution.