Local Java installation management
Functions
- find_
all_ java_ installations - Discovers all Java installations on the system.
- get_
java_ by_ version - Gets information about a specific Java installation by version.
- get_
java_ document - Gets the Java documentation directory.
- get_
java_ dyn_ lib - Gets the directory containing the JVM dynamic library.
- get_
java_ home - Gets detailed information about the current Java installation.
- get_
latest_ java - Gets the latest Java installation available on the system.