Human-readable Java spec parsing and matching ("Eclipse Adoptium v^17.0.0 ax86_64").
Human-readable Java specification parsing and matching.
A spec string like "Eclipse Adoptium v^17.0.0 ax86_64" describes a
desired Java installation by vendor, version constraint, and architecture.
Format: <vendor> v<constraint> a<arch>
| Part | Example | Meaning |
|---|---|---|
| Vendor | Eclipse Adoptium | Fuzzy-matched against name / vendor |
| Constraint | ^17.0.0 | Compatible with 17.0.0 (semver caret) |
| Architecture | x86_64 | Architecture substring match |
Supported constraint operators:
^17.0.0— compatible (≥17.0.0, <18.0.0)~17.0.0— approximately (≥17.0.0, <17.1.0)>=17.0.0,<=17.0.0,>17.0.0,<17.0.017.0.0— exact (no prefix)
Structs
- Java
Spec - A parsed Java installation query spec.
Enums
- Version
Req - A version constraint with an operator and target version.